scry.cli.results

Result-file naming, filesystem lifecycle, and EDN sanitization for the CLI.

Result-file naming, filesystem lifecycle, and EDN sanitization for the CLI.
raw docstring

edn-readable-dataclj

(edn-readable-data value)

Recursively coerce data into values readable by clojure.edn/read-string.

EDN scalar leaves pass through. Throwables retain class/message/stacktrace, common collection types recurse, arrays/iterables become vectors, and other objects become maps with class and pr-str detail.

Recursively coerce data into values readable by clojure.edn/read-string.

EDN scalar leaves pass through. Throwables retain class/message/stacktrace,
common collection types recurse, arrays/iterables become vectors, and other
objects become maps with class and pr-str detail.
raw docstring

encode-file-segmentclj

(encode-file-segment segment)

Encode a namespace or var-name segment for a deterministic result filename.

Encode a namespace or var-name segment for a deterministic result filename.
raw docstring

failure-entry?clj

(failure-entry? entry)

True when a canonical result entry should be written to a result file.

True when a canonical result entry should be written to a result file.
raw docstring

prepare-results-dir!clj

(prepare-results-dir! io-boundary)

Clear and recreate the CLI results directory for a run.

Clear and recreate the CLI results directory for a run.
raw docstring

result-file-nameclj

(result-file-name entry)

Return the namespace-prefixed result EDN filename for a canonical entry.

Return the namespace-prefixed result EDN filename for a canonical entry.
raw docstring

results-dirclj

(results-dir {:keys [cwd]})

Return the .scry-results directory for an IO boundary map containing :cwd.

Return the .scry-results directory for an IO boundary map containing :cwd.
raw docstring

write-result-files!clj

(write-result-files! dir entries)

Write readable EDN result files for failing/erroring canonical entries.

Returns a vector of written file paths.

Write readable EDN result files for failing/erroring canonical entries.

Returns a vector of written file paths.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries